With the Empress Dowager of China by Katharine A. Carl | Project Gutenberg
Description: Free kindle book and epub digitized and proofread by volunteers.
Keywords: ebook, ebooks, free ebooks, free books, book, books, audio books

# With the Empress Dowager of China by Katharine A. Carl

## Read now or download (free!)

| Choose how to read this book | Url | Size |  |  |
--- | --- | --- | --- | --- | --- | ---
| Read online (web) | https://www.gutenberg.org/ebooks/75210.html.images | 561 kB |  |  |
| EPUB3 (E-readers incl. Send-to-Kindle) | https://www.gutenberg.org/ebooks/75210.epub3.images | 3.8 MB |  |  |
| EPUB (older E-readers) | https://www.gutenberg.org/ebooks/75210.epub.images | 3.8 MB |  |  |
| EPUB (no images, older E-readers) | https://www.gutenberg.org/ebooks/75210.epub.noimages | 419 kB |  |  |
| Kindle | https://www.gutenberg.org/ebooks/75210.kf8.images | 4.6 MB |  |  |
| older Kindles | https://www.gutenberg.org/ebooks/75210.kindle.images | 4.5 MB |  |  |
| Plain Text UTF-8 | https://www.gutenberg.org/ebooks/75210.txt.utf-8 | 514 kB |  |  |
| Download HTML (zip) | https://www.gutenberg.org/cache/epub/75210/pg75210-h.zip | 4.3 MB |  |  |
| There may be more files related to this item.

## Similar Books

Readers also downloaded…

## About this eBook

Author | Carl, Katharine A. (Katharine Augusta), 1865-1938
Title | With the Empress Dowager of China
Original Publication | United States: The Century Co., 1905, pubdate 1907.
Note | Illustrated by the author and with photographs.
Credits | Aaron Adrignola, Richard Illner and the Online Distributed Proofreading Team at https://www.pgdp.net (This file was produced from images generously made available by The Internet Archive)
Language | English
LoC Class | DS: History: General and Eastern Hemisphere: Asia
Subject | Cixi, Empress dowager of China, 1835-1908
Subject | Empresses -- China -- Biography
Subject | China -- Court and courtiers
Category | Text
EBook-No. | 75210
Release Date | Jan 26, 2025
Copyright Status | Public domain in the USA.
Downloads | 685 downloads in the last 30 days.
Project Gutenberg eBooks are always free!